Búsqueda de sitios web

Mover buzón a Exchange Online con PowerShell


Después de instalar el Asistente de configuración híbrida (HCW), desea mover un buzón a Exchange Online con PowerShell. El término también se conoce como incorporación de un buzón a la nube. Entonces, ¿qué necesita completar en PowerShell para iniciar la migración del buzón? En este artículo, aprenderá cómo migrar un buzón a Exchange Online con PowerShell.

Cómo mover el buzón a Exchange Online con PowerShell

Para mover un buzón a Exchange Online con PowerShell, siga estos pasos:

1. Conéctese a Exchange Online PowerShell

Inicie PowerShell como administrador y conéctese a Exchange Online PowerShell.

Connect-ExchangeOnline

Nota: No está enviando el buzón local a Exchange Online. De hecho, está extrayendo el buzón local de Exchange Online. Es por eso que necesita conectarse a Exchange Online y ejecutar los comandos desde Exchange Online PowerShell.

2. Encuentre la URL del servidor remoto del punto final de migración

Obtenga la dirección URL del servidor remoto mediante el cmdlet Get-MigrationEndpoint. Lea más sobre cómo encontrar la URL de RemoteHostName para la migración de buzones de correo. El asistente de configuración híbrida creó este punto final de migración.

Get-MigrationEndpoint | Format-List Identity, RemoteServer

Aparece el siguiente resultado. Copie el valor de la URL de RemoteServer tal como lo necesitará en la siguiente parte.

Identity     : Hybrid Migration Endpoint - EWS (Default Web Site)
RemoteServer : mail.exoip.com

3. Mueva el buzón a Exchange Online con PowerShell

Cree una nueva solicitud de movimiento para mover el buzón principal y el buzón de archivo a Exchange Online. Complete los siguientes detalles:

  • -Identidad: Nombre del buzón o dirección de correo electrónico
  • -RemoteHostName: El servidor remoto que copió en el paso anterior
  • -TargetDeliveryDomain: dominio SMTP principal utilizado para los buzones de correo de la organización de Exchange Online
  • -RemoteCredential: Cuenta de administrador local con privilegios

Después de ejecutar el comando, aparecerá una solicitud de inicio de sesión de credencial. Complete la contraseña de las credenciales locales (RemoteCredential).

New-MoveRequest -Identity "Maisha.Lee@exoip.com" -Remote -RemoteHostName "mail.exoip.com" -TargetDeliveryDomain "exoip365.mail.onmicrosoft.com" -RemoteCredential (Get-Credential)

4. Mueva varios buzones de correo a Exchange Online con PowerShell

Cree un archivo CSV llamado Users.csv y colóquelo en el directorio C:\migration.

Abra el archivo CSV, asigne un nombre a la columna del encabezado Dirección de correo electrónico y complete todos los buzones que desee mover a Exchange Online.

Copie el siguiente script y cambie las primeras 3 líneas. Después de eso, ejecute el script.

$Mailboxes = Import-Csv "C:\Migration\Users.csv"
$RemoteHostName = "mail.exoip.com"
$TargetDeliveryDomain = "exoip365.mail.onmicrosoft.com"
$OnPremCred = (Get-Credential)

# Move mailboxes in CSV file to Exchange Online
foreach ($Mailbox in $Mailboxes) {
    $params = @{
        Identity             = $mailbox.EmailAddress
        Remote               = $true
        RemoteHostName       = $RemoteHostName
        TargetDeliveryDomain = $TargetDeliveryDomain
        RemoteCredential     = $OnPremCred
    }

    New-MoveRequest @params
}

5. Mueva el buzón principal solo a Exchange Online con PowerShell

Supongamos que la ubicación del buzón de archivo está en Exchange Online y la ubicación del buzón principal está en Exchange local. Cuando ejecuta el comando anterior, recibe el siguiente mensaje de error:

Debe especificar el parámetro PrimaryOnly
El usuario de destino "Maisha Lee" ya tiene un buzón de archivo.

Así se ve en la consola de PowerShell:

PS C:\> New-MoveRequest -Identity "Maisha.Lee@exoip.com" -Remote -RemoteHostName "mail.exoip.com" -TargetDeliveryDomain "exoip365.mail.onmicrosoft.com" -RemoteCredential (Get-Credential)
You must specify the PrimaryOnly parameter.
Target user 'Maisha Lee' already has an archive mailbox.
    + CategoryInfo          : NotSpecified: (:) [New-MoveRequest], MailboxReplicationPermanentException
    + FullyQualifiedErrorId : [Server=PAXP190MB1743,RequestId=3f8179c3-aa93-453f-9e14-d824968f34c4,TimeStamp=5/28/2022
    7:19:13 AM] [FailureCategory=Cmdlet-MailboxReplicationPermanentException] FE8B9422,Microsoft.Exchange.Management.
  Migration.MailboxReplication.MoveRequest.NewModernMoveRequest
    + PSComputerName        : outlook.office365.com

Debe agregar el parámetro -PrimaryOnly al comando.

Cree una nueva solicitud de movimiento para mover el buzón principal solo a Exchange Online. Complete los siguientes detalles:

  • -Identidad: Nombre del buzón o dirección de correo electrónico
  • -RemoteHostName: El servidor remoto que copió en el paso anterior
  • -PrimaryOnly: Mantener el valor vacío
  • -TargetDeliveryDomain: dominio SMTP principal utilizado para los buzones de correo de la organización de Exchange Online
  • -RemoteCredential: Cuenta de administrador local con privilegios

Después de ejecutar el comando, aparecerá una solicitud de inicio de sesión de credencial. Complete la contraseña de las credenciales locales (RemoteCredential).

New-MoveRequest -Identity "Maisha.Lee@exoip.com" -Remote -RemoteHostName "mail.exoip.com" -PrimaryOnly -TargetDeliveryDomain "exoip365.mail.onmicrosoft.com" -RemoteCredential (Get-Credential)

6. Mueva el buzón de archivo solo a Exchange Online con PowerShell

Debe agregar el parámetro -ArchiveOnly al comando.

Cree una nueva solicitud de movimiento para mover el buzón de archivo solo a Exchange Online. Complete los siguientes detalles:

  • -Identidad: Nombre del buzón o dirección de correo electrónico
  • -RemoteHostName: El servidor remoto que copió en el paso anterior
  • -ArchiveOnly: Mantener el valor vacío
  • -TargetDeliveryDomain: dominio SMTP principal utilizado para los buzones de correo de la organización de Exchange Online
  • -RemoteCredential: Cuenta de administrador local con privilegios

Después de ejecutar el comando, aparecerá una solicitud de inicio de sesión de credencial. Complete la contraseña de las credenciales locales (RemoteCredential).

New-MoveRequest -Identity "Maisha.Lee@exoip.com" -Remote -RemoteHostName "mail.exoip.com" -ArchiveOnly -TargetDeliveryDomain "exoip365.mail.onmicrosoft.com" -RemoteCredential (Get-Credential)

7. Obtener el estado del movimiento del buzón

Obtenga el estado de la solicitud de movimiento del buzón mediante el cmdlet Get-MoveRequest.

Get-MoveRequest -Identity "Maisha.Lee@exoip.com" | Get-MoveRequestStatistics

Ejecute el siguiente comando para obtener todas las solicitudes de movimiento de buzones.

Get-MoveRequest | Get-MoveRequestStatistics

El resultado muestra el estado del movimiento del buzón y el estado completado.

DisplayName StatusDetail TotalMailboxSize            TotalArchiveSize PercentComplete
----------- ------------ ----------------            ---------------- ---------------
Maisha Lee  Completed    32.11 MB (33,670,771 bytes) 0 B (0 bytes)    100

Si ese no es el caso y no puede completar la solicitud de movimiento del buzón, puede suspender y reanudar la solicitud de movimiento. Ayuda en la mayoría de situaciones cuando obtienes un estado fallido. Por ejemplo, el detalle de estado TransientFailure.

¿Le ayudó este artículo a migrar el buzón a Exchange Online con PowerShell? Espero que así sea.

Leer más: Complete el lote de migración con PowerShell »

Conclusión

Aprendió cómo mover un buzón a Exchange Online con PowerShell. Conéctese a Exchange Online PowerShell y ejecute los comandos como se muestra en el artículo. Recuerde monitorear el movimiento del buzón a Exchange Online hasta que se complete exitosamente.

¿Disfrutaste este artículo? También te puede interesar que el buzón de correo de destino no tenga una coincidencia de proxy SMTP. No olvides seguirnos y compartir este artículo.

Artículos relacionados